using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class MissionAssignmentsManager : CoreManager
{
	private Dictionary<string, MissionAssignment> _missionAssignments = new Dictionary<string, MissionAssignment>();
	
	public override void Initialize(SPMRandom spmRandom, GameWorld gameWorld, SpaceAgencyT playerSpaceAgency, DifficultyLevelT difficultyLevel)
	{
		MissionAssignmentSlot [] assignmentSlots;
		
		// MC-SATELLITE
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[3];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("BOOSTER_LOWERCASE"));
			assignmentSlots[1] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("SPACECRAFT_SYSTEMS"));
			assignmentSlots[2] = new MissionAssignmentSlot(1,PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("FLIGHT_DIRECTOR"));

			missionAssignment.FlightDirectorsSlotsIndices.Add(2);

			_missionAssignments.Add("MC-SATELLITE", missionAssignment);
		}
		
		// MC-PROBE
		{
			var missionAssignment = new MissionAssignment();
			
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[5];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("BOOSTER_LOWERCASE"));
			assignmentSlots[1] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("SPACECRAFT_SYSTEMS"));
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("NAVIGATION"));
			assignmentSlots[3] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("EXPERIMENTS"));
			assignmentSlots[4] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("FLIGHT_DIRECTOR"));

			missionAssignment.FlightDirectorsSlotsIndices.Add(4);
			
			_missionAssignments.Add("MC-PROBE", missionAssignment);
		}
		
		// MC-X-15
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[4];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("BOOSTER_LOWERCASE"));
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("TRAJECTORY"));
			assignmentSlots[2] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("SPACE_PLANE_SYSTEMS"));
			assignmentSlots[3] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, gameWorld.GetCommonGameWorldOrUIString("FLIGHT_DIRECTOR"));

			missionAssignment.FlightDirectorsSlotsIndices.Add(3);
			
			_missionAssignments.Add("MC-X-15", missionAssignment);
		}

		// MC-MERCURY_UNCREWED
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[9];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER");
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO");
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO");
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO");
			
			assignmentSlots[4] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "ENVIRONMENTAL");
			assignmentSlots[5] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES");
			assignmentSlots[6] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT");
			assignmentSlots[7] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SYSTEMS");
			assignmentSlots[8] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK");
			
			missionAssignment.FlightDirectorsSlotsIndices.Add(6);
			
			_missionAssignments.Add("MC-MERCURY_UNCREWED", missionAssignment);
		}
		
		// MC-MERCURY
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[11];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER");
			assignmentSlots[1] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SURGEON");
			assignmentSlots[2] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CAPCOM");
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO");
			assignmentSlots[4] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO");
			assignmentSlots[5] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO");
			
			assignmentSlots[6] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "ENVIRONMENTAL");
			assignmentSlots[7] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES");
			assignmentSlots[8] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT");
			assignmentSlots[9] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SYSTEMS");
			assignmentSlots[10] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK");

			missionAssignment.FlightDirectorsSlotsIndices.Add(8);

			_missionAssignments.Add("MC-MERCURY", missionAssignment);
		}

		// MC-GEMINI_UNCREWED
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[9];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER");
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO");
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO");
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO");
			
			assignmentSlots[4] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM");
			assignmentSlots[5] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK");
			
			assignmentSlots[6] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES");
			assignmentSlots[7] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFD");
			assignmentSlots[8] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT");
			
			missionAssignment.FlightDirectorsSlotsIndices.Add(7);
			missionAssignment.FlightDirectorsSlotsIndices.Add(8);
			
			_missionAssignments.Add("MC-GEMINI_UNCREWED", missionAssignment);
		}
		
		// MC-GEMINI
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[12];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER");
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO");
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO");
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO");
			
			assignmentSlots[4] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SURGEON");
			assignmentSlots[5] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM");
			assignmentSlots[6] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CAPCOM");
			assignmentSlots[7] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK");
			
			assignmentSlots[8] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES");
			assignmentSlots[9] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FAO");
			assignmentSlots[10] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFD");
			assignmentSlots[11] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT");

			missionAssignment.FlightDirectorsSlotsIndices.Add(10);
			missionAssignment.FlightDirectorsSlotsIndices.Add(11);
			
			_missionAssignments.Add("MC-GEMINI", missionAssignment);
		}

		// MC-GEMINI-AGENA
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[14];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER");
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO");
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO");
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO");
			
			assignmentSlots[4] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SURGEON");
			assignmentSlots[5] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM");
			assignmentSlots[6] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CAPCOM");
			assignmentSlots[7] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK");
			assignmentSlots[8] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AGENA I");
			assignmentSlots[9] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AGENA II");
			
			assignmentSlots[10] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES");
			assignmentSlots[11] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FAO");
			assignmentSlots[12] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFD");
			assignmentSlots[13] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT");

			missionAssignment.FlightDirectorsSlotsIndices.Add(12);
			missionAssignment.FlightDirectorsSlotsIndices.Add(13);
			
			_missionAssignments.Add("MC-GEMINI-AGENA", missionAssignment);
		}

		// MC-LUNAR_GEMINI_UNCREWED
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[11];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER"); // BOOSTER
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO"); // RETRO
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO"); // FIDO
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO"); // GUIDO
			
			assignmentSlots[4] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM"); // EECOM
			assignmentSlots[5] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK"); // NETWORK
			
			assignmentSlots[6] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES"); // PROCEDURES
			assignmentSlots[7] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFD"); // AFD
			assignmentSlots[8] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT"); // FLIGHT
			
			assignmentSlots[9] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "INCO"); // INCO
			assignmentSlots[10] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GNC"); // GNC
			
			missionAssignment.FlightDirectorsSlotsIndices.Add(7);
			missionAssignment.FlightDirectorsSlotsIndices.Add(8);
			
			_missionAssignments.Add("MC-LUNAR_GEMINI_UNCREWED", missionAssignment);
		}

		// MC-LUNAR_GEMINI
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[14];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER"); // BOOSTER
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO"); // RETRO
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO"); // FIDO
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO"); // GUIDO
			
			assignmentSlots[4] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SURGEON"); // SURGEON
			assignmentSlots[5] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM"); // EECOM
			assignmentSlots[6] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CAPCOM"); // CAPCOM
			assignmentSlots[7] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK"); // NETWORK
			
			assignmentSlots[8] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES"); // PROCEDURES
			assignmentSlots[9] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FAO"); // FAO
			assignmentSlots[10] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFD"); // AFD
			assignmentSlots[11] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT"); // FLIGHT
			
			assignmentSlots[12] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "INCO"); // INCO
			assignmentSlots[13] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GNC"); // GNC

			missionAssignment.FlightDirectorsSlotsIndices.Add(10);
			missionAssignment.FlightDirectorsSlotsIndices.Add(11);
			
			_missionAssignments.Add("MC-LUNAR_GEMINI", missionAssignment);
		}

		// MC-DA_GEMINI_UNCREWED
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[11];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER"); // BOOSTER
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO"); // RETRO
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO"); // FIDO
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO"); // GUIDO
			
			assignmentSlots[4] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM"); // EECOM
			assignmentSlots[5] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK"); // NETWORK
			
			assignmentSlots[6] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES"); // PROCEDURES
			assignmentSlots[7] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFD"); // AFD
			assignmentSlots[8] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT"); // FLIGHT
			
			assignmentSlots[9] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "INCO"); // INCO
			assignmentSlots[10] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GNC"); // GNC
			
			missionAssignment.FlightDirectorsSlotsIndices.Add(7);
			missionAssignment.FlightDirectorsSlotsIndices.Add(8);
			
			_missionAssignments.Add("MC-DA_GEMINI_UNCREWED", missionAssignment);
		}

		// MC-DA_GEMINI
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[14];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER"); // BOOSTER
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO"); // RETRO
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO"); // FIDO
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO"); // GUIDO
			
			assignmentSlots[4] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SURGEON"); // SURGEON
			assignmentSlots[5] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM"); // EECOM
			assignmentSlots[6] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CAPCOM"); // CAPCOM
			assignmentSlots[7] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK"); // NETWORK
			
			assignmentSlots[8] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "PROCEDURES"); // PROCEDURES
			assignmentSlots[9] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FAO"); // FAO
			assignmentSlots[10] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFD"); // AFD
			assignmentSlots[11] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT"); // FLIGHT
			
			assignmentSlots[12] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "INCO"); // INCO
			assignmentSlots[13] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GNC"); // GNC

			missionAssignment.FlightDirectorsSlotsIndices.Add(10);
			missionAssignment.FlightDirectorsSlotsIndices.Add(11);
			
			_missionAssignments.Add("MC-DA_GEMINI", missionAssignment);
		}

		// MC-APOLLO_UNCREWED
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[13];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER"); // BOOSTER
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO"); // RETRO
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO"); // FIDO
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO"); // GUIDO
			
			assignmentSlots[4] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM"); // EECOM
			assignmentSlots[5] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GNC"); // GNC
			assignmentSlots[6] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "TELMU"); // TELMU
			assignmentSlots[7] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "CONTROL"); // CONTROL
			
			assignmentSlots[8] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "INCO"); // INCO
			assignmentSlots[9] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "O&P"); // O&P
			assignmentSlots[10] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFLIGHT"); // AFLIGHT
			assignmentSlots[11] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT"); // FLIGHT
			assignmentSlots[12] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK"); // NETWORK
			
			missionAssignment.FlightDirectorsSlotsIndices.Add(10);
			missionAssignment.FlightDirectorsSlotsIndices.Add(11);
			
			_missionAssignments.Add("MC-APOLLO_UNCREWED", missionAssignment);
		}

		// MC-APOLLO
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[16];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER"); // BOOSTER
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO"); // RETRO
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO"); // FIDO
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO"); // GUIDO
			
			assignmentSlots[4] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SURGEON"); // SURGEON
			assignmentSlots[5] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CAPCOM"); // CAPCOM
			assignmentSlots[6] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM"); // EECOM
			assignmentSlots[7] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GNC"); // GNC
			assignmentSlots[8] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "TELMU"); // TELMU
			assignmentSlots[9] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "CONTROL"); // CONTROL
			
			assignmentSlots[10] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "INCO"); // INCO
			assignmentSlots[11] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "O&P"); // O&P
			assignmentSlots[12] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFLIGHT"); // AFLIGHT
			assignmentSlots[13] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT"); // FLIGHT
			assignmentSlots[14] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FAO"); // FAO
			assignmentSlots[15] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK"); // NETWORK

			missionAssignment.FlightDirectorsSlotsIndices.Add(12);
			missionAssignment.FlightDirectorsSlotsIndices.Add(13);

			_missionAssignments.Add("MC-APOLLO", missionAssignment);
		}

		// MC-APOLLO_NO_LM_UNCREWED
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[11];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER"); // BOOSTER
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO"); // RETRO
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO"); // FIDO
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO"); // GUIDO
			
			assignmentSlots[4] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM"); // EECOM
			assignmentSlots[5] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GNC"); // GNC
			
			assignmentSlots[6] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "INCO"); // INCO
			assignmentSlots[7] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "O&P"); // O&P
			assignmentSlots[8] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFLIGHT"); // AFLIGHT
			assignmentSlots[9] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT"); // FLIGHT
			assignmentSlots[10] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK"); // NETWORK
			
			missionAssignment.FlightDirectorsSlotsIndices.Add(8);
			missionAssignment.FlightDirectorsSlotsIndices.Add(9);
			
			_missionAssignments.Add("MC-APOLLO_NO_LM_UNCREWED", missionAssignment);
		}

		// MC-APOLLO_NO_LM
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[14];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "BOOSTER"); // BOOSTER
			assignmentSlots[1] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "RETRO"); // RETRO
			assignmentSlots[2] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FIDO"); // FIDO
			assignmentSlots[3] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GUIDO"); // GUIDO
			
			assignmentSlots[4] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "SURGEON"); // SURGEON
			assignmentSlots[5] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CAPCOM"); // CAPCOM
			assignmentSlots[6] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "EECOM"); // EECOM
			assignmentSlots[7] = new MissionAssignmentSlot(1, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "GNC"); // GNC
			
			assignmentSlots[8] = new MissionAssignmentSlot(3, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "INCO"); // INCO
			assignmentSlots[9] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "O&P"); // O&P
			assignmentSlots[10] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "AFLIGHT"); // AFLIGHT
			assignmentSlots[11] = new MissionAssignmentSlot(5, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FLIGHT"); // FLIGHT
			assignmentSlots[12] = new MissionAssignmentSlot(4, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "FAO"); // FAO
			assignmentSlots[13] = new MissionAssignmentSlot(2, PersonnelManager.EmployeeTypeT.MISSIONCONTROL, "NETWORK"); // NETWORK
			
			missionAssignment.FlightDirectorsSlotsIndices.Add(10);
			missionAssignment.FlightDirectorsSlotsIndices.Add(11);
			
			_missionAssignments.Add("MC-APOLLO_NO_LM", missionAssignment);
		}

		// FC-X-15
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[1];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-X-15", missionAssignment);
		}

		// FC-PKA
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[1];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COSMONAUT"));
			
			_missionAssignments.Add("FC-PKA", missionAssignment);
		}

		// FC-DUAL_PKA
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COSMONAUT") + " A");
			
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COSMONAUT") + " B");
			
			_missionAssignments.Add("FC-DUAL_PKA", missionAssignment);
		}
		
		// FC-MERCURY
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[1];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("ASTRONAUT"));
			
			_missionAssignments.Add("FC-MERCURY", missionAssignment);
		}

		// FC-DUAL_MERCURY
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("ASTRONAUT") + " A");

			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("ASTRONAUT") + " B");
			
			_missionAssignments.Add("FC-DUAL_MERCURY", missionAssignment);
		}

		// FC-VOSTOK
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[1];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COSMONAUT"));
			
			_missionAssignments.Add("FC-VOSTOK", missionAssignment);
		}

		// FC-DUAL_VOSTOK
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COSMONAUT") + " A");

			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COSMONAUT") + " B");
			
			_missionAssignments.Add("FC-DUAL_VOSTOK", missionAssignment);
		}
		
		// FC-GEMINI
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-GEMINI", missionAssignment);
		}
		
		// FC-DUAL_GEMINI
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[4];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER") + " A");
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT") + " A");
			
			assignmentSlots[2] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER") + " B");
			assignmentSlots[3] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT") + " B");
			
			_missionAssignments.Add("FC-DUAL_GEMINI", missionAssignment);
		}
		
		// FC-GEMINI_EOR
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-GEMINI_EOR", missionAssignment);
		}

		// FC-VOSKHOD
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-VOSKHOD", missionAssignment);
		}

		// FC-DUAL_VOSKHOD
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[4];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER") + " A");
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT") + " A");
			
			assignmentSlots[2] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER") + " B");
			assignmentSlots[3] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT") + " B");
			
			_missionAssignments.Add("FC-DUAL_VOSKHOD", missionAssignment);
		}

		// FC-SOYUZ_7K-L1
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-SOYUZ_7K-L1", missionAssignment);
		}

		// FC-SOYUZ_7K-L3_LOK
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-SOYUZ_7K-L3_LOK", missionAssignment);
		}

		// FC-DUAL_SOYUZ_7K-L3_LOK
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[4];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER") + " A");
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT") + " A");
			
			assignmentSlots[2] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER") + " B");
			assignmentSlots[3] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT") + " B");
			
			_missionAssignments.Add("FC-DUAL_SOYUZ_7K-L3_LOK", missionAssignment);
		}

		// FC-LK-700
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-LK-700", missionAssignment);
		}

		// FC-GEMINI_LOR
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-GEMINI_LOR", missionAssignment);
		}

		// FC-GEMINI_DA
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[2];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("PILOT"));
			
			_missionAssignments.Add("FC-GEMINI_DA", missionAssignment);
		}

		// FC-APOLLO
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[3];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CDR");
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CMP");
			assignmentSlots[2] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "LMP");
			
			_missionAssignments.Add("FC-APOLLO", missionAssignment);
		}

		// FC-DUAL_APOLLO
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[6];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CDR");
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CMP");
			assignmentSlots[2] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "LMP");

			assignmentSlots[3] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CDR");
			assignmentSlots[4] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "CMP");
			assignmentSlots[5] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, "LMP");
			
			_missionAssignments.Add("FC-DUAL_APOLLO", missionAssignment);
		}

		// FC-SOYUZ_7K-OK
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[3];

            assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("FLIGHT_ENG"));
			assignmentSlots[2] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("RESEARCH_ENG"));
			
			_missionAssignments.Add("FC-SOYUZ_7K-OK", missionAssignment);
		}
		
		// FC-DUAL_SOYUZ_7K-OK
		{
			var missionAssignment = new MissionAssignment();
			assignmentSlots = missionAssignment.AssignmentsSlots = new MissionAssignmentSlot[6];
			
			assignmentSlots[0] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[1] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("FLIGHT_ENG"));
			assignmentSlots[2] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("RESEARCH_ENG"));
			
			assignmentSlots[3] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("COMMANDER"));
			assignmentSlots[4] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("FLIGHT_ENG"));
			assignmentSlots[5] = new MissionAssignmentSlot(0, PersonnelManager.EmployeeTypeT.ASTRONAUTS, gameWorld.GetCommonGameWorldOrUIString("RESEARCH_ENG"));
			
			_missionAssignments.Add("FC-DUAL_SOYUZ_7K-OK", missionAssignment);
		}
	}
	
	public override void Reset()
	{
		_missionAssignments.Clear();
	}
	
	public override void UpdateLanguageChange(object sender)
	{
	}
	
	public int GetNumSlots(string assignmentsLayoutID)
	{
		var assigmentsSlots = GetAssignmentSlots(assignmentsLayoutID);
		return (assigmentsSlots != null) ? assigmentsSlots.Length : 0;
	}
	
	public int GetNumSlots(string assignmentsLayoutID, PersonnelManager.EmployeeTypeT employeeType)
	{
		int numSlots = 0;
		var assigmentsSlots = GetAssignmentSlots(assignmentsLayoutID);
		if (assigmentsSlots != null)
		{
			foreach (var assignmentSlot in assigmentsSlots)
			{
				if (assignmentSlot.EmployeeType == employeeType)
				{
					++numSlots;
				}
			}
		}
		return numSlots;
	}

	public HashSet<int> GetFlightDirectorsSlotsIndices(string assignmentsLayoutID)
	{
		MissionAssignment missionAssignment;
		if (_missionAssignments.TryGetValue(assignmentsLayoutID, out missionAssignment))
		{
			return missionAssignment.FlightDirectorsSlotsIndices;
		}
		return null;
	}
	
	public void GetSpecialityIndexForAssignmentSlot(string assignmentsLayoutID, int slotID, out int specialityIndex)
	{
		PersonnelManager.EmployeeTypeT dummyEmployeeType;
		GetSpecialityIndexAndEmployeeTypeForAssignmentSlot(assignmentsLayoutID, slotID, out specialityIndex,
			out dummyEmployeeType);
	}
	
	public void GetSpecialityIndexAndEmployeeTypeForAssignmentSlot(string assignmentsLayoutID, int slotID,
		out int specialityIndex, out PersonnelManager.EmployeeTypeT employeeType)
	{
		string dummySlotName;
		GetSpecialityIndexEmployeeTypeAndSlotNameForAssignmentSlot(assignmentsLayoutID, slotID, out specialityIndex,
			out employeeType, out dummySlotName);
	}

	public void GetSpecialityIndexEmployeeTypeAndSlotNameForAssignmentSlot(string assignmentsLayoutID, int slotID,
		out int specialityIndex, out PersonnelManager.EmployeeTypeT employeeType, out string slotName)
	{
		var missionAssignmentsSlots = GetAssignmentSlots(assignmentsLayoutID);
		specialityIndex = missionAssignmentsSlots[slotID].SpecialityIndex;
		employeeType = missionAssignmentsSlots[slotID].EmployeeType;
		slotName = missionAssignmentsSlots[slotID].Name;
	}

	public string GetSlotName(string assignmentsLayoutID, int slotID)
	{
		var missionAssignmentsSlots = GetAssignmentSlots(assignmentsLayoutID);
		return ((missionAssignmentsSlots != null) && (slotID < missionAssignmentsSlots.Length)) ? missionAssignmentsSlots[slotID].Name : string.Empty;
	}
	
	#region Private utility functions
	
	private MissionAssignmentSlot [] GetAssignmentSlots(string assignmentsLayoutID)
	{
		MissionAssignment missionAssignment;
		if (_missionAssignments.TryGetValue(assignmentsLayoutID, out missionAssignment))
		{
			return missionAssignment.AssignmentsSlots;
		}
		return null;
	}
	
	#endregion
}
